@@ -48,7 +48,7 @@ use vars qw/@ISA @EXPORT @EXPORT_OK @EXPORT_TAGS
             $TIMEOUT @MODULES %MODULES %METHODS $AUTOLOAD
             @CURRENCY_RATES_MODULES $USE_EXPERIMENTAL_UA/;
 
-our $VERSION = '1.66_01'; # TRIAL VERSION
+our $VERSION = '1.66_02'; # TRIAL VERSION
 
 @CURRENCY_RATES_MODULES = qw/
     AlphaVantage
@@ -94,6 +94,7 @@ our $VERSION = '1.66_01'; # TRIAL VERSION
     Sinvestor
     StockData
     Stooq
+    SwissFundData
     TesouroDireto
     TMX
     Tradegate
@@ -600,8 +601,12 @@ sub fetch {
   }
 
   {
+    # Setting no critic to avoid Stricture disabled failure
+    # in t/04-critic.t
+    ## no critic
     no strict 'vars';
     our $VERSION = '0.00' unless defined $VERSION;
+    ## use critic
     unless ($ENV{"FQ_NOCOUNT"}) {
       # Temporary Counting - not concerned about return code
       my $COUNT_URL =
@@ -1731,6 +1736,7 @@ http://www.gnucash.org/
   Finance::Quote::SIX,
   Finance::Quote::StockData,
   Finance::Quote::Stooq,
+  Finance::Quote::SwissFundData,
   Finance::Quote::TSP,
   Finance::Quote::TMX,
   Finance::Quote::TesouroDireto,
@@ -1739,6 +1745,7 @@ http://www.gnucash.org/
   Finance::Quote::Union,
   Finance::Quote::YahooJSON,
   Finance::Quote::YahooWeb,
+  Finance::Quote::XETRA,
   Finance::Quote::ZA
 
 You should have received the Finance::Quote hacker's guide with this package.
